% End to end model - solving the ODEs in diffusion advection


% Code for my Master's Thesis: On the Cell-to-Cell Extracellular Vesicle Transmission within the Brain
% Case ﻿Study: Alzheimer's Disease
% Author: Dorsa Kabiri
% Date: 07/10/2023
% Supervisors: Mladen Veletić, Martin Damrath, Ilangko Balasingham,
% Norwegian University of Science and Technology


% Transmitter part is from the solution in: 
% M. Veletić, M. T. Barros, H. Arjmandi, S. Balasubramaniam, and I. Balasingham, “Modeling
% of Modulated Exosome Release From Differentiated Induced Neural Stem Cells for Targeted
% Drug Delivery,” IEEE Transactions on NanoBioscience, vol. 19, no. 3, pp. 357–367, 7 2020

clc
clear all;

%% Defining the time vector
step = 1;                   %[ms]sas
step_sec = step/1000;       %[s]
t_end = 10;
t_start = 1e-12;
num_samples = (t_end - t_start)/step_sec;   
t_vector = linspace( 1e-12, t_end, num_samples);       %[s]

%% TRANSMITTER
npulse = 1;
time = 01e-012:step:1e3; %[ms]
amp = 40;          %[\muA/cm^2; pA]
offset = 50;

%% Parameter Set: ---
% NEURONAL CELLS
% Nominal values for electrical activity
% Voltages given in [mV]
% Conductances given in [nS or, equivalently, mS/cm^3]
% Time constants given in [ms]
% Capacitance given in [\muF/cm^2]
gK = 36;
gNa = 120;
gL = 0.3;
VNa = 50;
VK = -70;
VL = -54.4;
cm = 1;

VCa = 65;
VSOC = 0;
gSOC = 0;
gCaL = 0.7;
gCaPQ = 0.6;
gCaT = 0.4;
gKa = 1;
gKATP = 0.295;
VmCaL = -30;
VmCaPQ = -5;
SmCaL = 10;
SmCaPQ = 10;
VhCaL = -33;
VhCaPQ = -33;
ShCaL = -5;
ShCaPQ = -5;
taumVCaL = 1;
taumVCaPQ = 1;
taum0CaL = 0.05;
taum0CaPQ = 0.05;
VtaumCaL = -23;
VtaumCaPQ = -23;
StaumCaL = 20;
StaumCaPQ = 20;
tauhVCaL = 60;
tauhVCaPQ = 60;
tauh0CaL = 51;
tauh0CaPQ = 51;
VtauhCaL = 0;
VtauhCaPQ = 0;
StauhCaL = 20;
StauhCaPQ = 20;
VmCaT = -49;
SmCaT = 4;
VhCaT = -52;
ShCaT = -5;
taumVCaT = 15;
taum0CaT = 0;
VtaumCaT = -50;
StaumCaT = 12;
tauhVCaT = 20;
tauh0CaT = 5;
VtauhCaT = -50;
StauhCaT = 15;

VmNa = -30;
SmNa = 4;
VhNa = -52;
ShNa = -8;
taumVNa = 6;
taum0Na = 0.05;
VtaumNa = -50;
StaumNa = 10;
tauhVNa = 120;
tauh0Na = 0.5;
VtauhNa = -50;
StauhNa = 8;
VmKa = -45;
SmKa = 10;
VhKa = -68;
ShKa = -10;
taumVKa = 0;
taum0Ka = 0.1;
tauhVKa = 60;
tauh0Ka = 5;
VtauhKa = 5;
StauhKa = 20;
VmK = -25;
SmK = 23;
taumVK = 1.5;
taum0K = 15;
VtaumK = -10;
StaumK = 25;

f = 0.01;
Volmud = 2.618e-19; % [L]
Volc = 5.725e-13;   % [L]
NPQ = 0.0001;
Bmud = 264;         % [1/ms]
kPMCA = 0.3;        % [1/ms]
pleak = 3e-4;       % [1/ms]
nPQ = 4;
nL = 4;
nm = 4;
alpha = 5.18e-15;   % [\mumol/pA/ms]
Volm = 5.149e-14;   % [L]
VolcDIVVoler = 31;
NL = 200;
Bm = 0.128;         % [1/ms]
kSERCA = 0.1;       % [1/ms]
KPQ = 2;
KL = 50;            % [muM]
Km = 2;             % [muM]
%% Derivatives
% x(1) = Vm;
% x(2) = mCaL;
% x(3) = mCaPQ;
% x(4) = mCaT;
% x(5) = mNa;   -->m
% x(6) = mK;    -->n
% x(7) = mKa;
% x(8) = hCaL;
% x(9) = hCaPQ;
% x(10) = hCaT;
% x(11) = hNa;  -->h
% x(12) = hKa;
% x(13) = CaL;
% x(14) = CaPQ;
% x(15) = Cam;
% x(16) = Cac;
% x(17) = Caer;
%-----------------2---------------------------------------------------------
f1 = @(t,x) [
    -(gK*x(6)^4*(x(1)-VK) + gNa*x(5)^3*x(11)*(x(1)-VNa) + gL*(x(1)-VL)- controlSignal(t,amp,time,step,npulse, offset))/cm;
    (funcminf(x(1), VmCaL, SmCaL) - x(2))./functaum(x(1), taumVCaL, VtaumCaL, StaumCaL, taum0CaL);
    (funcminf(x(1), VmCaPQ, SmCaPQ) - x(3))./functaum(x(1), taumVCaPQ, VtaumCaPQ, StaumCaPQ, taum0CaPQ);
    (funcminf(x(1), VmCaT, SmCaT) - x(4))./functaum(x(1), taumVCaT, VtaumCaT, StaumCaT, taum0CaT);
    0.1*(x(1)+40)/(1-exp(-(x(1)+40)/10))*(1-x(5))-4*exp(-(x(1)+65)/18)*x(5);
    0.01*(x(1)+55)/(1-exp(-(x(1)+55)/10))*(1-x(6))-0.125*exp(-(x(1)+65)/80)*x(6);
    (funcminf(x(1), VmKa, SmKa) - x(7))./functaum(x(1), taumVKa, VtaumK, StaumK, taum0Ka);
    (funcminf(x(1), VhCaL, ShCaL) - x(8))./functaum(x(1), tauhVCaL, VtauhCaL, StauhCaL, tauh0CaL);
    (funcminf(x(1), VhCaPQ, ShCaPQ) - x(9))./functaum(x(1), tauhVCaPQ, VtauhCaPQ, StauhCaPQ, tauh0CaPQ);
    (funcminf(x(1), VhCaT, ShCaT) - x(10))./functaum(x(1), tauhVCaT, VtauhCaT, StauhCaT, tauh0CaT);
    0.07*exp(-(x(1)+65)/20)*(1-x(11))-1/(1+exp(-(x(1)+35)/10))*x(11);
    (funcminf(x(1), VhKa, ShKa) - x(12))./functaum(x(1), tauhVKa, VtauhKa, StauhKa, tauh0Ka);
    (-f*alpha*gCaL.*(x(1)-VCa)./NL./Volmud - f*Bmud*(x(13)-x(15)));
    (-f*alpha*gCaPQ.*(x(1)-VCa)./NPQ./Volmud*0 - f*Bmud*(x(14)-x(15)));
    (f*(-alpha*(gCaT.*x(4)^3*x(10)*(x(1)-VCa))/Volm + NPQ*Volmud/Volm*Bmud*x(3)*x(9)*(x(14)-x(15)) + NL*Volmud/Volm*Bmud*x(2)^2*x(8)*(x(13)-x(15)) - Volc/Volm*kPMCA*x(15) + Volc/Volm*Bm*(x(15)-x(16))));
    (f*(Bm*(x(15)-x(16)) + pleak*(x(17)-x(16)) - kSERCA*x(16)));
    (-f*VolcDIVVoler*(pleak*(x(17)-x(16)) - kSERCA*x(16)))
    ];

% ODE with the initial condition
xinit = [-65 zeros(1,16)];
t_start = tic;
tspan_ode = [0 time(end)];
[t1, sol] = ode45(f1, time, xinit);
t_end = toc(t_start);
fprintf('\n     [ OK ]');
fprintf('\n     Elapsed %.4f s',t_end);


%% Control Signal & Plasma Membrane Potential
i_stimulation = controlSignal(t1,amp,time,step,npulse,offset);
Vm = sol(:, 1);
figure,
subplot(2,2,[1,2]), plot(t1/1000,i_stimulation, 'LineWidth', 1); hold on; grid minor;
title('Control signal', 'Interpreter', 'latex', 'FontSize', 11);
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$i_m$ [$\mu$A/cm$^2$]', 'Interpreter', 'latex', ...
    'FontSize', 11);
subplot(2,2,[3,4]), plot(t1/1000, Vm, 'LineWidth', 1); hold on; grid minor;
title('Plasma membrane potential', 'Interpreter', 'latex', 'FontSize', 11);
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$v_m$ [mV]', 'Interpreter', 'latex', ...
    'FontSize', 11);
%% Activation and Inactivation Functions from ODEs
% Activation Functions
mCaL = sol(:,2);
mCaPQ = sol(:,3);
mCaT = sol(:,4);
mNa = sol(:,5);
mK = sol(:,6);
mKa = sol(:,7);

% % Inactivation Functions
hCaL = sol(:,8);
hCaPQ = sol(:,9);
hCaT = sol(:,10);
hNa = sol(:,11);
hKa = sol(:,12);

%% Calcium Concentrations from ODEs
CaLo = sol(:,13);
CaPQo = sol(:,14);
Cam = sol(:,15);
Cac = sol(:,16);
Caer = sol(:,17);

figure,
subplot(1,2,1), plot(t1/1000, CaLo, 'LineWidth', 1); hold on; grid minor;
title('$[\mathrm{Ca}]_{L}$', 'Interpreter', 'latex', 'FontSize', 11);
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$\mu$mol/L', 'Interpreter', 'latex', 'FontSize', 11);
subplot(1,2,2), plot(t1/1000, Cam, 'LineWidth', 1); hold on; grid minor;
title('$[\mathrm{Ca}]_m$', 'Interpreter', 'latex', 'FontSize', 11);
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$\mu$mol/L', 'Interpreter', 'latex', 'FontSize', 11);

%% Exocytosis Equations
% Release Rates
rateCaL = mCaL.^2.*hCaL.*(CaLo.^nL)./(CaLo.^nL + KL.^nL) + ...
    (1 - mCaL.^2.*hCaL).*(Cam.^nL)./(Cam.^nL + KL.^nL);
rateCam = (Cam.^Km)./(Cam.^nm + Km.^nm);

%% Released Concentrations
cExoL = zeros(size(rateCaL));
cExom = zeros(size(rateCam));
for i = 1:length(rateCaL)
    cExoL(i) = trapz(rateCaL(1:i))*step;
    cExom(i) = trapz(rateCam(1:i))*step;
end
figure,

plot(t1/1000, (rateCaL+rateCam)/(6.022e014), 'LineWidth', 2); hold on; grid minor;
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$\mathrm{particle}$/L/ms', 'Interpreter', 'latex', 'FontSize', 11);
ylim([0, 8e-17]);
title('$\mathcal{R}^{\mathrm{(neuron)}}$', sprintf('$g_{Na}=%g$ ms/${cm}^3$', gNa) , 'Interpreter', 'latex', 'FontSize', 11);

%% Channel 
d = 1e-12;    %  (From Exosome Brain Delivery Paper)
lambda = 2.5;  %  for brain extracellular matrix , (Exosome Brain delivery paper) 
K = d/(lambda^2);
kd = 0.0002;   %  (From Exosome Brain Delivery Paper)
alphaa = 0.2;   %  typical values : 0.1 < alpha < 0.3

% Velocities
vx = 0E-06 ;
vy = 0E-06 ;
vz = 0E-06 ;

% Position vectors
x = [1e-06 2e-6 3e-6 4e-6 5e-06];
%x = 2e-06;
y = 0e-6;
z = 0e-6;

%% channel responce
% input signal
transmitted_EVs = (rateCam+rateCaL)/alphaa*step;

% Green Function
G = zeros(length(x), length(t_vector));


% concentration Matrix
C = zeros(length(x), length(t_vector)); 


for k = 1:length(x)   % for each x position          
    for n = 1:length(t_vector)  % for each t point 
        G(k , n) = 1/(6.022e014)*((4*pi*t_vector(n)*K)^(-3/2))*exp(-kd*t_vector(n))*exp(-((x(k)-vx*t_vector(n))^2)/(4*K*t_vector(n)))*exp(-((y-vy*t_vector(n))^2)/(4*K*t_vector(n)))*exp(-((z-vz*t_vector(n))^2)/(4*K*t_vector(n)));  
    end  
    Cr = conv(G(k, :), transmitted_EVs); % convolution in time [umol/liter]
    C(k,:) = Cr(1:length(G(k, :)));
end

figure,
plot(t_vector,G); grid minor;
title('Channel response at $\mathrm{\textbf{x}} = (x, 0, 0)$', sprintf('$\\lambda$=$%g$ ,  $g_{Na}=%g$ ms/${cm}^3$', double(lambda), gNa), 'Interpreter', 'latex', 'FontSize', 11);
legend('$x = $' + string(x*1e06) + ' $\mathrm{\mu m}$', 'Interpreter', 'latex', 'Location', 'northeast')
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$G{(\mathrm{\textbf{x}}, t)}$','Interpreter', 'latex', 'FontSize', 11) 


figure,
plot(t_vector,C); grid minor;
title('EV concentration in channel at $\mathrm{\textbf{x}} = (x, 0, 0)$',sprintf('$\\lambda$=$%g$ ,  $g_{Na}=%g$ ms/${cm}^3$', double(lambda), gNa), 'Interpreter', 'latex', 'FontSize', 11);
legend('$x = $' + string(x*1e06) + ' $\mathrm{\mu m}$', 'Interpreter', 'latex', 'Location', 'northeast')
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$C{(\mathrm{\textbf{x}}, t)}  [particle/L]$','Interpreter', 'latex', 'FontSize', 11) 



%% Receiver

kb = 0.13;  % binding rate (1/s)
N =  0.1;     % binding sites
kr = 0.11;  % recycling rate
ki = 1;     % internalization rate
kh = 0;     % half-life rate


%% Solving ODE
q_A     = zeros(size(C));
q_AR    = zeros(size(C));
q_int   = zeros(size(C));
for j = 1:length(x)
    odefunc = @(t,y) [kb*(N-y(1))*y(3) - kr*y(1) - ki*y(1);... % ODE for binding
        ki*y(1);... % ODE for internalization                                       
        -kb*(N-y(1))*y(3) + kr*y(1) + interp1(t_vector, diff([0 C(j, :)])./step_sec, t, 'pchip')]; % ODE for environmental EVs (half-life is included in CIR)
    option = odeset('NonNegative', [1 2 3]);
    [t, Y]      = ode45(odefunc, t_vector, [0; 0; 0],option)
    q_AR(j, :)  = Y(:, 1).';                            % Bound EVs to Rx
    q_int(j, :) = Y(:, 2).';                            % Internalized EVs into Rx
    q_A(j, :)   = Y(:, 3).';                            % EVs at Rx
end

%% plotting
figure,
plot(t_vector, q_AR); grid minor;
title('Number of bound EVs at $\mathrm{\textbf{x}} = (x, 0, 0)$', sprintf('$\\lambda$=$%g$ , $g_{Na}=%g$ ms/${cm}^3$', double(lambda), gNa) , 'Interpreter', 'latex', 'FontSize', 11)
legend('$x = $' + string(x*1e06) + ' $\mathrm{\mu m}$', 'Interpreter', 'latex', 'Location', 'southeast')
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$q_{AR}(t) [particle/L]$', 'Interpreter', 'latex', 'FontSize', 11);

figure
plot(t_vector, q_int); grid minor;
title('Number of internalized EVs at $\mathrm{\textbf{x}} = (x, 0, 0)$', sprintf('$\\lambda$=$%g$ ,  $g_{Na}=%g$ ms/${cm}^3$', double(lambda), gNa) , 'Interpreter', 'latex', 'FontSize', 11)
legend('$x = $' + string(x*1e06) + ' $\mathrm{\mu m}$', 'Interpreter', 'latex', 'Location', 'northwest')
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$q_{p}(t) [particle/L]$', 'Interpreter', 'latex', 'FontSize', 11);

figure
plot(t_vector, q_A); grid minor;
title('Number of EVs in channel at $\mathrm{\textbf{x}} = (x, 0, 0)$', sprintf('$\\lambda$=$%g$ , $g_{Na}=%g$ ms/${cm}^3$', double(lambda), gNa) ,  'Interpreter', 'latex', 'FontSize', 11)
legend('$x = $' + string(x*1e06) + ' $\mathrm{\mu m}$', 'Interpreter', 'latex', 'Location', 'northeast')
xlabel('Time [s]', 'Interpreter', 'latex', 'FontSize', 11);
ylabel('$q_{A}(t) [particle/L]$', 'Interpreter', 'latex', 'FontSize', 11);