function [x] = solvewolfram_conf(kf, kb, ki, kd, D, r)
% Analytical WolframAlpha solution to the following equation system
%  
%         a + b + c = (1 + kf/(4pi D r)) * sqrt(D)/r
%   a c + b c + a b = kb + ki - kd
%            a b c  = (kb + ki + (kf ki)/(4pi D r)- kd (1 + kf/(4pi D r))) sqrt(D)/r
%
%   Input:
%       kf:         forward rate in m^3/s
%       kb:         backward rate in 1/s
%       ki:         internalization rate in 1/s
%       kd:         degradation rate in 1/s
%       D:          diffusion coefficient in m^2/s
%       r:          receiver radius in m
%       
%   Output:
%       x:          vector with solution x = (a b c)
% 
% md ~ 24.04.2023

x = zeros(1, 3);

%% conference solution [Schober]
x(1) = -((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/...
      (6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
         (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
         sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
             (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
           4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*...
      ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
        (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
        sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
            (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
          4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3);
x(2) = (1/(8*pi))*(kf/(r^2*sqrt(D)) + (4*sqrt(D)*pi)/r - 4*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/...
         (6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
            (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
            sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
              4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
           (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
           (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
           sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
               (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
             4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + ...
      sqrt((-(kf/(r^2*sqrt(D))) - (4*sqrt(D)*pi)/r + 4*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/...
             (6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                    (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                    (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*...
             ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
               (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(...
                ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                   (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)))^2 - ...
        16*pi*(4*kb*pi - 4*kd*pi + 4*ki*pi - (1/(r^2*sqrt(D)))*(kf*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/...
              (6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                 (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                 (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                     (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                     (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*...
              ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                    (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                  4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3))) - (1/r)*(4*sqrt(D)*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - ...
             (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/(6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - ...
                 (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + ...
                 (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - ...
                     (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + ...
                     (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + ...
             (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                    (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                    (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3))) + ...
          4*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/(6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + ...
                 (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + ...
                 (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                 sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                     (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                   4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
                (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                    (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
                    (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3))^...
            2)));
x(3) = (1/(4*pi))*(kf/(3*r^2*sqrt(D)) + (4*sqrt(D)*pi)/(3*r) + ...
      kf^2/(3*2^(2/3)*r^4*D*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
          (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
          (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
              (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
              (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) - ...
      (2^(1/3)*kf^2)/(3*r^4*D*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
          (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
          (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
              (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
              (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) - ...
      (4*2^(1/3)*kf*pi)/(3*r^3*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
          (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
          (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
              (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
              (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + ...
      (8*2^(1/3)*kb*pi^2)/((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
         (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
         (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
             (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
             (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3) - ...
      (8*2^(1/3)*kd*pi^2)/((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
         (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
         (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
             (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
             (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3) - ...
      (8*2^(1/3)*D*pi^2)/(3*r^2*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
          (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
          (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
              (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
              (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + ...
      (8*2^(1/3)*ki*pi^2)/((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
         (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
         (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
             (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
             (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3) - ...
      (1/(6*2^(1/3)))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
         (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
         sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
             (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
           4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3) - ...
      (1/2)*sqrt((-(kf/(r^2*sqrt(D))) - (4*sqrt(D)*pi)/r + 4*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/...
              (6*2^(2/3)*pi*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                 (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                 (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + ...
                     (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + ...
                     (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*...
              ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                    (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                  4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)))^2 - 16*pi*(4*kb*pi - 4*kd*pi + 4*ki*pi - ...
           (1/(r^2*sqrt(D)))*(kf*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/(6*2^(2/3)*pi*...
                ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                  (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                  sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                      (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                    4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                 (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
                 (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                     (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/...
                      r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^...
                (1/3))) - (1/r)*(4*sqrt(D)*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/(6*2^(2/3)*pi*...
                ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                  (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                  sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                      (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                    4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                 (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
                 (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                     (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/...
                      r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^...
                (1/3))) + 4*pi*(-((-kf - 4*r*D*pi)/(12*r^2*sqrt(D)*pi)) - (48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))/(6*2^(2/3)*pi*...
                ((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                  (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + ...
                  sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + ...
                      (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + ...
                    4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^(1/3)) + (1/(12*2^(1/3)*pi))*((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                 (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/r - ...
                 (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r + sqrt(((2*kf^3)/(r^6*D^(3/2)) + (24*kf^2*pi)/(r^5*sqrt(D)) - ...
                     (144*kb*kf*pi^2)/(r^2*sqrt(D)) - (288*kd*kf*pi^2)/(r^2*sqrt(D)) + (96*sqrt(D)*kf*pi^2)/r^4 + (288*kf*ki*pi^2)/(r^2*sqrt(D)) + (1152*kb*sqrt(D)*pi^3)/...
                      r - (1152*kd*sqrt(D)*pi^3)/r + (128*D^(3/2)*pi^3)/r^3 + (1152*sqrt(D)*ki*pi^3)/r)^2 + 4*(48*(kb - kd + ki)*pi^2 - (-kf - 4*r*D*pi)^2/(r^4*D))^3))^...
                (1/3))^2)));